@@ -1,26 +1,39 @@
-import base64
-import email
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+
+"""
+Models declaration for application ``django_mailbox``.
+"""
+
+from email.encoders import encode_base64
 from email.message import Message as EmailMessage
 from email.utils import formatdate, parseaddr
-from email.encoders import encode_base64
+from quopri import encode as encode_quopri
+import base64
+import email
+import logging
 import mimetypes
 import os.path
-from quopri import encode as encode_quopri
 import sys
 import uuid
 
-from django.conf import settings
-from django.core.mail.message import make_msgid
-from django.core.files.base import ContentFile
-from django.db import models
-from django_mailbox.transports import Pop3Transport, ImapTransport,\
-    MaildirTransport, MboxTransport, BabylTransport, MHTransport, \
-    MMDFTransport, GmailImapTransport
-from django_mailbox.signals import message_received
 import six
 from six.moves.urllib.parse import parse_qs, unquote, urlparse
 
-from .utils import convert_header_to_unicode
+from django.conf import settings
+from django.core.files.base import ContentFile
+from django.core.mail.message import make_msgid
+from django.db import models
+from django.utils.translation import ugettext as _
+
+from .utils import convert_header_to_unicode, get_body_from_message
+from django_mailbox.signals import message_received
+from django_mailbox.transports import Pop3Transport, ImapTransport, \
+    MaildirTransport, MboxTransport, BabylTransport, MHTransport, \
+    MMDFTransport, GmailImapTransport
+
+
+logger = logging.getLogger(__name__)
 
 
 STRIP_UNALLOWED_MIMETYPES = getattr(
@@ -28,6 +41,7 @@ STRIP_UNALLOWED_MIMETYPES = getattr(
     'DJANGO_MAILBOX_STRIP_UNALLOWED_MIMETYPES',
     False
 )
+
 ALLOWED_MIMETYPES = getattr(
     settings,
     'DJANGO_MAILBOX_ALLOWED_MIMETYPES',
@@ -36,6 +50,7 @@ ALLOWED_MIMETYPES = getattr(
         'text/html'
     ]
 )
+
 TEXT_STORED_MIMETYPES = getattr(
     settings,
     'DJANGO_MAILBOX_TEXT_STORED_MIMETYPES',
@@ -44,11 +59,13 @@ TEXT_STORED_MIMETYPES = getattr(
         'text/html'
     ]
 )
+
 ALTERED_MESSAGE_HEADER = getattr(
     settings,
     'DJANGO_MAILBOX_ALTERED_MESSAGE_HEADER',
     'X-Django-Mailbox-Altered-Message'
 )
+
 ATTACHMENT_INTERPOLATION_HEADER = getattr(
     settings,
     'DJANGO_MAILBOX_ATTACHMENT_INTERPOLATION_HEADER',
@@ -64,10 +81,15 @@ class ActiveMailboxManager(models.Manager):
 
 
 class Mailbox(models.Model):
-    name = models.CharField(max_length=255)
-    uri = models.CharField(
+    name = models.CharField(
+        _(u'Name'),
         max_length=255,
-        help_text=(
+    )
+
+    uri = models.CharField(
+        _(u'URI'),
+        max_length=255,
+        help_text=(_(
             "Example: imap+ssl://myusername:mypassword@someserver <br />"
             "<br />"
             "Internet transports include 'imap' and 'pop3'; "
@@ -76,14 +98,16 @@ class Mailbox(models.Model):
             "<br />"
             "Be sure to urlencode your username and password should they "
             "contain illegal characters (like @, :, etc)."
-        ),
+        )),
         blank=True,
         null=True,
         default=None,
     )
+
     from_email = models.CharField(
+        _(u'From email'),
         max_length=255,
-        help_text=(
+        help_text=(_(
             "Example: MailBot &lt;mailbot@yourdomain.com&gt;<br />"
             "'From' header to set for outgoing email.<br />"
             "<br />"
@@ -91,19 +115,21 @@ class Mailbox(models.Model):
             "setting is unnecessary.<br />"
             "If you send e-mail without setting this, your 'From' header will'"
             "be set to match the setting `DEFAULT_FROM_EMAIL`."
-        ),
+        )),
         blank=True,
         null=True,
         default=None,
     )
+
     active = models.BooleanField(
-        help_text=(
+        _(u'Active'),
+        help_text=(_(
             "Check this e-mail inbox for new e-mail messages during polling "
             "cycles.  This checkbox does not have an effect upon whether "
             "mail is collected here when this mailbox receives mail from a "
             "pipe, and does not affect whether e-mail messages can be "
             "dispatched from this mailbox. "
-        ),
+        )),
         blank=True,
         default=True,
     )
@@ -346,34 +372,62 @@ class UnreadMessageManager(models.Manager):
 
 
 class Message(models.Model):
-    mailbox = models.ForeignKey(Mailbox, related_name='messages')
-    subject = models.CharField(max_length=255)
-    message_id = models.CharField(max_length=255)
+    mailbox = models.ForeignKey(
+        Mailbox,
+        related_name='messages',
+        verbose_name=_(u'Mailbox'),
+    )
+
+    subject = models.CharField(
+        _(u'Subject'),
+        max_length=255
+    )
+
+    message_id = models.CharField(
+        _(u'Message ID'),
+        max_length=255
+    )
+
     in_reply_to = models.ForeignKey(
         'django_mailbox.Message',
         related_name='replies',
         blank=True,
         null=True,
+        verbose_name=_(u'In reply to'),
     )
+
     from_header = models.CharField(
+        _('From header'),
         max_length=255,
     )
-    to_header = models.TextField()
+
+    to_header = models.TextField(
+        _(u'To header'),
+    )
+
     outgoing = models.BooleanField(
+        _(u'Outgoing'),
         default=False,
         blank=True,
     )
 
-    body = models.TextField()
+    body = models.TextField(
+        _(u'Body'),
+    )
+
     encoded = models.BooleanField(
+        _(u'Encoded'),
         default=False,
-        help_text='True if the e-mail body is Base64 encoded'
+        help_text=_('True if the e-mail body is Base64 encoded'),
     )
 
     processed = models.DateTimeField(
+        _('Processed'),
         auto_now_add=True
     )
+
     read = models.DateTimeField(
+        _(u'Read'),
         default=None,
         blank=True,
         null=True,
@@ -443,28 +497,22 @@ class Message(models.Model):
 
     @property
     def text(self):
-        return self.get_text_body()
-
-    def get_text_body(self):
-        def get_body_from_message(message):
-            body = ''
-            for part in message.walk():
-                if (
-                    part.get_content_maintype() == 'text'
-                    and part.get_content_subtype() == 'plain'
-                ):
-                    charset = part.get_content_charset()
-                    this_part = part.get_payload(decode=True)
-                    if charset:
-                        this_part = this_part.decode(charset, 'replace')
-
-                    body += this_part
-            return body
-
+        """
+        Returns the message body matching content type 'text/plain'.
+        """
         return get_body_from_message(
-            self.get_email_object()
+            self.get_email_object(), 'text', 'plain'
         ).replace('=\n', '').strip()
 
+    @property
+    def html(self):
+        """
+        Returns the message body matching content type 'text/html'.
+        """
+        return get_body_from_message(
+            self.get_email_object(), 'text', 'html'
+        ).replace('\n', '').strip()
+
     def _rehydrate(self, msg):
         new = EmailMessage()
         if msg.is_multipart():
@@ -556,9 +604,19 @@ class MessageAttachment(models.Model):
         related_name='attachments',
         null=True,
         blank=True,
+        verbose_name=_('Message'),
+    )
+
+    headers = models.TextField(
+        _(u'Headers'),
+        null=True,
+        blank=True,
+    )
+
+    document = models.FileField(
+        _(u'Document'),
+        upload_to='mailbox_attachments/%Y/%m/%d/'
     )
-    headers = models.TextField(null=True, blank=True)
-    document = models.FileField(upload_to='mailbox_attachments/%Y/%m/%d/')
 
     def delete(self, *args, **kwargs):
         self.document.delete()
